@@ -133,7 +133,7 @@ def current_timestamp(p_arg):
             frmt = "%Y-%m-%d %H:%M:%S"
     else:
         frmt = "%Y-%m-%d %H:%M:%S"
-    return strftime(frmt, localtime())
+    return datetime.datetime.now().strftime(frmt)
 
 
 # 第一个参数是seed的名字
